require("colors");
var util = require("util");

var unit;

function assert(pass, message){
    console.log(
        ((pass? "✓" : "×").bold+" "+unit+":\t"+message)[pass? "green" : "red"]
    )
}

function eq( result, expected, msg ){
    var pass = result === expected;
    assert(
        pass,
        pass? msg : msg+"\texpected "+util.inspect(expected)+" but got "+util.inspect(result)
    )
}

var facade = require("../src");

unit = "Parsing";

var fragments = {
    //Normal element
    "<b>asdf</b>": "<b>asdf</b>",
    
    //Element left open
    "<b>asdf": "<b>asdf</b>",
    
    //Empty element
    "<br>a": "<br />a",
    
    //Text before
    "a <strong>a</strong>": "a <strong>a</strong>",
    
    //Text after
    "<strong>a</strong> a": "<strong>a</strong> a",
    
    //Both
    "a <strong>a</strong> a": "a <strong>a</strong> a",
    
    //Double quoted attribute
    '<div foo="bar" />':'<div foo=bar />',
    
    //Single quoted attribute
    "<div foo='bar' />":'<div foo=bar />',
    
    //Non-quoted attribute
    '<div foo=bar />':'<div foo=bar />'
    
},x;


for(x in fragments){
    eq(
        facade(x).render(), fragments[x], x
    )
}

unit = "Selection";
var document = facade("<div>\
    <span><b>Hi</b></span>\
    <b id='test'>Hola</b>\
    <em foo=bar>Hi</em>\
</div>")

var selectors = {
    "b": "<b>Hi</b><b id=test>Hola</b>"
}

for(x in selectors){
    eq(
        document.find(x).render(),
        selectors[x],
        x
    )
}


unit = "Manipulation";

eq(
    facade("<div><b>Hi</b></div>").replace("b", "<strong>Hola</strong>").render(),
    "<div><strong>Hola</strong></div>",
    "replace"
)

